@@ -109,7 +109,7 @@ def getBpNames(inifile: str):
         list of column names for body-part pose-estimation probability values
     """
 
-    x_cols, y_cols, p_cols = ([], [], [])
+    x_cols, y_cols, p_cols = [], [], []
     config = read_config_file(ini_path=inifile)
     project_path = read_config_entry(config, 'General settings', 'project_path', data_type='folder_path')
     body_part_lst_path = str(os.path.join(project_path, 'logs', 'measures', 'pose_configs', 'bp_names', 'project_bp_names.csv'))
