@@ -186,6 +186,7 @@ class AdvancedLabellingInterface(object):
                             text='\n\n Keyboard shortcuts for frame navigation: \n Right Arrow = +1 frame'
                                  '\n Left Arrow = -1 frame'
                                  '\n Ctrl + s = Save annotations file'
+                                 '\n Ctrl + a = +1 frame and keep choices'
                                  '\n Ctrl + l = Last frame'
                                  '\n Ctrl + o = First frame')
         self.key_presses_lbl.grid(sticky=S)
@@ -194,6 +195,7 @@ class AdvancedLabellingInterface(object):
 
     def bind_shortcut_keys(self):
         self.main_window.bind('<Control-s>', lambda x: self.save_results())
+        self.main_window.bind('<Control-a>', lambda x: self.advance_frame(new_frm_number= int(self.current_frm_n.get() + 1), keep_prior_img_cb_status=True))
         self.main_window.bind('<Right>', lambda x: self.advance_frame(new_frm_number= int(self.current_frm_n.get() + 1)))
         self.main_window.bind('<Left>', lambda x: self.advance_frame(new_frm_number= int(self.current_frm_n.get() - 1)))
         self.main_window.bind('<Control-l>', lambda x: self.advance_frame(new_frm_number = self.max_frm_no))
@@ -225,7 +227,7 @@ class AdvancedLabellingInterface(object):
         self.video_frame.image = self.current_frm_pil
         self.video_frame.grid(row=0, column=0)
 
-    def advance_frame(self, new_frm_number: int=None):
+    def advance_frame(self, new_frm_number: int=None, keep_prior_img_cb_status=False):
         self.check_integrity_of_multiple_classifiers()
         if new_frm_number > self.max_frm_no:
             print("FRAME {} CANNOT BE SHOWN - YOU ARE VIEWING THE FINAL FRAME OF THE VIDEO (FRAME NUMBER {})".format(str(new_frm_number), str(self.max_frm_no)))
@@ -237,23 +239,38 @@ class AdvancedLabellingInterface(object):
             self.current_frm_n = IntVar(value=0)
             self.change_frm_box.delete(0, END)
             self.change_frm_box.insert(0, self.current_frm_n.get())
-        elif new_frm_number != self.current_frm_n.get():
+        elif (new_frm_number != self.current_frm_n.get()) and (not keep_prior_img_cb_status):
             self.save_behavior_in_frm()
+            self.create_print_statements()
             self.current_frm_n = IntVar(value=new_frm_number)
             for target in self.target_lst:
                 new_frame_annotation = self.data_df_targets[target].loc[int(self.current_frm_n.get())]
+                print(new_frame_annotation)
                 if new_frame_annotation == 0:
                     self.check_absent_vars[target].set(value=1)
+                    self.check_present_vars[target].set(value=0)
                 elif new_frame_annotation == 1:
                     self.check_present_vars[target].set(value=1)
+                    self.check_absent_vars[target].set(value=0)
                 else:
                     self.check_present_vars[target].set(value=0)
                     self.check_absent_vars[target].set(value=0)
             self.change_frm_box.delete(0, END)
             self.change_frm_box.insert(0, self.current_frm_n.get())
-            self.create_print_statements()
             self.read_frm(frm_number=int(self.current_frm_n.get()))
-
+        elif (new_frm_number != self.current_frm_n.get()) and (keep_prior_img_cb_status):
+            self.create_print_statements()
+            self.save_behavior_in_frm()
+            self.current_frm_n = IntVar(value=new_frm_number)
+            for target in self.target_lst:
+                new_frame_annotation = self.data_df_targets[target].loc[int(self.current_frm_n.get() -1)]
+                if new_frame_annotation == 0:
+                    self.check_absent_vars[target].set(value=1)
+                elif new_frame_annotation == 1:
+                    self.check_present_vars[target].set(value=1)
+            self.change_frm_box.delete(0, END)
+            self.change_frm_box.insert(0, self.current_frm_n.get())
+            self.read_frm(frm_number=int(self.current_frm_n.get()))
 
     def save_behavior_in_frm(self, selection: str=None):
         for target in self.target_lst:
