@@ -1,5 +1,7 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
+import time
+
 import cv2
 import pandas as pd
 from simba.rw_dfs import read_df, save_df
@@ -145,12 +147,14 @@ class LabellingInterface(object):
         self.check_behavior_lbl.config(font=("Calibri", 16))
         self.check_behavior_lbl.grid(sticky=N)
 
-        self.checkVar, self.checkbox = {}, {}
+        self.checkboxes = {}
         for target_cnt, target in enumerate(self.target_lst):
-            self.checkVar[target] = IntVar()
-            self.checkbox[target] = Checkbutton(self.check_frame, text=target, variable=self.checkVar[target], command=lambda: self.__save_behavior_in_frm(frame_number=int(self.current_frm_n.get()), target=target))
-            self.checkbox[target].grid(row=target_cnt + 1, sticky=W)
-            self.checkVar[target].set(self.data_df_targets[target].iloc[self.current_frm_n.get()])
+            self.checkboxes[target] = {}
+            self.checkboxes[target]['name'] = target
+            self.checkboxes[target]['var'] = IntVar()
+            self.checkboxes[target]['cb'] = Checkbutton(self.check_frame, text=target, variable=self.checkboxes[target]['var'], command=lambda k=self.checkboxes[target]['name']: self.save_behavior_in_frm(frame_number=int(self.current_frm_n.get()), target=k))
+            self.checkboxes[target]['cb'].grid(row=target_cnt + 1, sticky=W)
+            self.checkboxes[target]['var'].set(self.data_df_targets[target].iloc[self.current_frm_n.get()])
 
         self.range_on = IntVar(value=0)
         self.range_frames = Frame(self.main_window)
@@ -188,6 +192,7 @@ class LabellingInterface(object):
                             text='\n\n Keyboard shortcuts for frame navigation: \n Right Arrow = +1 frame'
                                  '\n Left Arrow = -1 frame'
                                  '\n Ctrl + s = Save annotations file'
+                                 '\n Ctrl + a = +1 frame and keep choices'
                                  '\n Ctrl + l = Last frame'
                                  '\n Ctrl + o = First frame')
         self.key_presses_lbl.grid(sticky=S)
@@ -196,6 +201,7 @@ class LabellingInterface(object):
 
     def __bind_shortcut_keys(self):
         self.main_window.bind('<Control-s>', lambda x: self.__save_results())
+        self.main_window.bind('<Control-a>', lambda x: self.__advance_frame(new_frm_number=int(self.current_frm_n.get() + 1), save_and_keep_checks=True))
         self.main_window.bind('<Right>', lambda x: self.__advance_frame(new_frm_number= int(self.current_frm_n.get() + 1)))
         self.main_window.bind('<Left>', lambda x: self.__advance_frame(new_frm_number= int(self.current_frm_n.get() - 1)))
         self.main_window.bind('<Control-l>', lambda x: self.__advance_frame(new_frm_number = self.max_frm_no))
@@ -227,8 +233,7 @@ class LabellingInterface(object):
         self.video_frame.image = self.current_frm_pil
         self.video_frame.grid(row=0, column=0)
 
-    def __advance_frame(self, new_frm_number: int=None):
-        print(new_frm_number, self.current_frm_n.get())
+    def __advance_frame(self, new_frm_number: int=None, save_and_keep_checks=False):
         if new_frm_number > self.max_frm_no:
             print("FRAME {} CANNOT BE SHOWN - YOU ARE VIEWING THE FINAL FRAME OF THE VIDEO (FRAME NUMBER {})".format(str(new_frm_number), str(self.max_frm_no)))
             self.current_frm_n = IntVar(value=self.max_frm_no)
@@ -244,10 +249,16 @@ class LabellingInterface(object):
             self.current_frm_n = IntVar(value=new_frm_number)
             self.change_frm_box.delete(0, END)
             self.change_frm_box.insert(0, self.current_frm_n.get())
-            for target in self.target_lst:
-                self.checkVar[target].set(self.data_df_targets[target].loc[int(self.current_frm_n.get())])
+            if not save_and_keep_checks:
+                for target in self.target_lst:
+                    self.checkboxes[target]['var'].set(self.data_df_targets[target].loc[int(self.current_frm_n.get())])
+            else:
+                for target in self.target_lst:
+                    self.checkboxes[target]['var'].set(self.data_df_targets[target].loc[int(self.current_frm_n.get() -1)])
+                    self.save_behavior_in_frm(target=target)
             self.__read_frm(frm_number=int(self.current_frm_n.get()))
 
+
     def __save_behavior_in_range(self, start_frm=None, end_frm=None):
         if not self.range_on.get():
             print('SAVE RANGE ERROR: TO SAVE RANGE OF FRAMES, TICK THE `Frame range` checkbox before clicking `Save Range`')
@@ -257,42 +268,14 @@ class LabellingInterface(object):
             check_int('END FRAME', int(end_frm), max_value=self.max_frm_no, min_value=0)
             for frm_no in range(int(start_frm), int(end_frm) + 1):
                 for target in self.target_lst:
-                    self.data_df_targets[target].loc[frm_no] = self.checkVar[target].get()
+                    self.data_df_targets[target].loc[frm_no] = self.checkboxes[target]['var'][target].get()
             self.__read_frm(frm_number=int(end_frm))
             self.change_frm_box.delete(0, END)
             self.change_frm_box.insert(0, end_frm)
         self.__create_print_statements(frame_range=True, start_frame=start_frm, end_frame=end_frm)
 
-    def __save_behavior_in_frm(self, frame_number=None, target=None):
-        self.data_df_targets[target].loc[int(self.current_frm_n.get())] = self.checkVar[target].get()
-
-    def save_checkboxes(self):
-        if self.range_on.get():
-            start_frm, end_frm = int(self.first_frame.get()), int(self.last_frame.get())
-            if start_frm < 0:
-                print("FRAME RANGE ERROR: START FRAME {} IS LESS THAN ZERO AND CANNOT BE SHOWN".format(str(start_frm)))
-                raise ValueError("FRAME RANGE ERROR: START FRAME {} IS LESS THAN ZERO AND CANNOT BE SHOWN".format(str(start_frm)))
-            elif end_frm > self.max_frm_no:
-                print("FRAME RANGE ERROR: END FRAME {} IS MORE THAN THE MAX VIDEO FRAME ({}) AND CANNOT BE SHOWN".format(str(end_frm), str(self.max_frm_no)))
-                raise ValueError("FRAME RANGE ERROR: END FRAME {} IS MORE THAN THE MAX VIDEO FRAME ({}) AND CANNOT BE SHOWN".format(str(end_frm), str(self.max_frm_no)))
-            elif start_frm == end_frm:
-                print("FRAME RANGE ERROR: START FRAME AND END FRAME IS SET TO THE SAME VALUE ({}) AND DOES NOT REPRESENT A RANGE".format(str(end_frm)))
-                raise ValueError("FRAME RANGE ERROR: START FRAME AND END FRAME IS SET TO THE SAME VALUE ({}) AND DOES NOT REPRESENT A RANGE".format(str(end_frm)))
-            elif start_frm > end_frm:
-                print("FRAME RANGE ERROR: START FRAME ({}) IS LARGER THAB THE END FRAME ({}). PLEASE SPECIFY A RANGE OF FRAMES WHERE THE START FRAME PRECEDE THE END FRAME".format(str(start_frm), str(end_frm)))
-                raise ValueError("FRAME RANGE ERROR: START FRAME ({}) IS LARGER THAB THE END FRAME ({}). PLEASE SPECIFY A RANGE OF FRAMES WHERE THE START FRAME PRECEDE THE END FRAME".format(str(start_frm), str(end_frm)))
-            else:
-                for frm_cnt in range(start_frm, end_frm + 1):
-                    for target in self.target_lst:
-                        self.data_df_targets.at[frm_cnt, target] = self.checkVar[target].get()
-                self.__advance_frame(new_frm_number=end_frm)
-        else:
-            for target in self.target_lst:
-                self.data_df_targets.at[int(self.current_frm_n.get()), target] = self.checkVar[target].get()
-            self.current_frm_n = IntVar(value=int(self.current_frm_n.get()) + 1)
-            self.change_frm_box.delete(0, END)
-            self.change_frm_box.insert(0, int(self.current_frm_n.get()))
-            print(self.data_df_targets)
+    def save_behavior_in_frm(self, frame_number=None, target=None):
+        self.data_df_targets[target].loc[int(self.current_frm_n.get())] = self.checkboxes[target]['var'].get()
 
     def __save_results(self):
         self.save_df = read_df(self.features_extracted_file_path, self.file_type)
@@ -313,7 +296,7 @@ class LabellingInterface(object):
         print('USER FRAME SELECTION(S):')
         if not frame_range:
             for target in self.target_lst:
-                target_present_choice = self.checkVar[target].get()
+                target_present_choice = self.checkboxes[target]['var'].get()
                 if (target_present_choice == 0):
                     print('{} ABSENT IN FRAME {}'.format(target, self.current_frm_n.get()))
                 if (target_present_choice == 1):
@@ -321,7 +304,7 @@ class LabellingInterface(object):
 
         if frame_range:
             for target in self.target_lst:
-                target_present_choice = self.checkVar[target].get()
+                target_present_choice = self.checkboxes[target]['var'].get()
                 if (target_present_choice == 1):
                     print('{} PRESENT IN FRAMES {} to {}'.format(target, str(start_frame), str(end_frame)))
                 elif (target_present_choice == 0):
