@@ -28,6 +28,7 @@ import platform
 import pickle
 import subprocess
 from datetime import datetime
+from simba.extract_frames_fast import video_to_frames
 import simba
 
 def get_video_meta_data(video_path: str):
@@ -844,10 +845,6 @@ def convert_parquet_to_csv(directory: str):
     ----------
     directory: str
         Path to directory holding parquet files
-
-    Returns
-    -------
-    None
     """
 
     if not os.path.isdir(directory):
@@ -896,339 +893,64 @@ def convert_csv_to_parquet(directory: str):
         print('Saved {}...'.format(new_file_path))
     print('SIMBA COMPLETE: {} csv files in {} converted to parquet'.format(str(len(files_found)), directory))
 
-def change_img_format(directory: str,
-                      file_type_in: str,
-                      file_type_out: str):
+
+def archive_processed_files(config_path: str,
+                            archive_name: str):
     """
-    Helper to convert file type of all image files in a folder.
+    Helper to archive files within a SimBA project.
 
     Parameters
     ----------
-    directory: str
-        Path to directory holding csv files
-    file_type_in: str
-        Input file type
-    file_type_out: str
-        Output file type
-
-    Returns
-    -------
-    None
-    """
-    if not os.path.isdir(directory):
-        print('SIMBA ERROR: {} is not a valid directory'.format(directory))
-        raise NotADirectoryError
-    files_found = glob.glob(directory + '/*.{}'.format(file_type_in))
-    if len(files_found) < 1:
-        print('SIMBA ERROR: No {} files (with .{} file ending) found in the {} directory'.format(file_type_in, file_type_in, directory))
-        raise ValueError
-    print('{} image files found in {}...'.format(str(len(files_found)), directory))
-    for file_path in files_found:
-        im = Image.open(file_path)
-        save_name = file_path.replace('.' + str(file_type_in), '.' + str(file_type_out))
-        im.save(save_name)
-        os.remove(file_path)
-    print('SIMBA COMPLETE: Files in {} directory converted to {}'.format(directory, file_type_out))
-
-
-def clahe_enhance_video(file_path: str):
-    """
-    Helper to convert a single video file to clahe-enhanced greyscale .avi file. The result is saved with prefix
-    ``CLAHE_`` in the same directory as in the input file.
-
-    Parameters
-    ----------
-    file_path: str
-        Path to video file.
-
-    Returns
-    -------
-    None
+    config_path: str
+        Path to SimBA project ``project_config.ini``.
+    archive_name: str
+        Name of archive.
     """
 
-    check_file_exist_and_readable(file_path=file_path)
-    dir, file_name, file_ext = get_fn_ext(filepath=file_path)
-    save_path = os.path.join(dir, 'CLAHE_{}.avi'.format(file_name))
-    video_meta_data = get_video_meta_data(file_path)
-    fourcc = cv2.VideoWriter_fourcc(*'XVID')
-    print('Applying CLAHE on video {}, this might take awhile...'.format(file_name))
-    cap = cv2.VideoCapture(file_path)
-    writer = cv2.VideoWriter(save_path, fourcc, video_meta_data['fps'], (video_meta_data['height'], video_meta_data['width']), 0)
-    clahe_filter = cv2.createCLAHE(clipLimit=2, tileGridSize=(16, 16))
-    try:
-        frm_cnt = 0
-        while True:
-            ret, img = cap.read()
-            if ret:
-                frm_cnt += 1
-                img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
-                clahe_frm = clahe_filter.apply(img)
-                writer.write(clahe_frm)
-                print('CLAHE converted frame {}/{}'.format(str(frm_cnt), str(video_meta_data['frame_count'])))
-    except Exception as se:
-        print(se.args)
-        print('CLAHE conversion failed for video {}'.format(file_name))
-        raise ValueError
+    config = read_config_file(config_path)
+    file_type = read_config_entry(config, 'General settings', 'workflow_file_type', 'str', 'csv')
+    project_path = read_config_entry(config, 'General settings', 'project_path', data_type='folder_path')
+    videos_dir = os.path.join(project_path, 'videos')
+    csv_dir = os.path.join(os.path.dirname(config_path), 'csv')
+    log_path = os.path.join(project_path, 'logs')
+    video_info_path = os.path.join(log_path, 'video_info.csv')
+    csv_subdirs, file_lst = [], []
+    for content_name in os.listdir(csv_dir):
+        if os.path.isdir(os.path.join(csv_dir, content_name)):
+            csv_subdirs.append(os.path.join(csv_dir, content_name))
 
+    for subdirectory in csv_subdirs:
+        subdirectory_files = [x for x in glob.glob(subdirectory + '/*') if os.path.isfile(x)]
+        for file_path in subdirectory_files:
+            directory, file_name, ext = get_fn_ext(os.path.join(subdirectory, file_path))
+            if ext == '.{}'.format(file_type):
+                file_lst.append(os.path.join(subdirectory, file_path))
 
-def extract_frame_range(file_path: str,
-                        start_frame: int,
-                        end_frame: int):
-    """
-    Helper to extract a user-defined range of frames from a video file and save those in png format. Images
-    are saved in a folder with the suffix `_frames` within the same directory as the video file.
-
-    Parameters
-    ----------
-    file_path: str
-        Path to video file.
-    start_frame: int
-        First frame in range to extract.
-    end_frame: int
-        Last frame in range to extract.
-
-    Returns
-    -------
-    None
-    """
-
-    check_file_exist_and_readable(file_path=file_path)
-    video_meta_data = get_video_meta_data(file_path)
-    check_int(name='start frame', value=start_frame, min_value=0)
-    file_dir, file_name, file_ext = get_fn_ext(filepath=file_path)
-    check_int(name='end frame', value=end_frame, max_value=video_meta_data['frame_count'])
-    frame_range = list(range(int(start_frame), int(end_frame) + 1))
-    save_dir = os.path.join(file_dir, file_name + '_frames')
-    cap = cv2.VideoCapture(file_path)
-    if not os.path.exists(save_dir): os.makedirs(save_dir)
-    for frm_cnt, frm_number in enumerate(frame_range):
-        cap.set(1, frm_number)
-        ret, frame = cap.read()
-        frm_save_path = os.path.join(save_dir, '{}.{}'.format(str(frm_number), 'png'))
-        cv2.imwrite(frm_save_path,frame)
-        print('Frame {} saved (Frame {}/{})'.format(str(frm_number), str(frm_cnt), str(len(frame_range))))
-    print('SIMBA COMPLETE: {} frames extracted for video {}'.format(str(len(frame_range)), file_name))
-
-
-
-
-def change_single_video_fps(file_path: str,
-                            fps: int):
-    """
-    Helper to change the fps of a single video file. Results are stored in the same directory as in the input file with
-    the suffix ``_fps_new_fps``.
-
-    Parameters
-    ----------
-    file_path: str
-        Path to video file.
-    fps: int
-        Fps of the new video file
-    """
-
-    check_file_exist_and_readable(file_path=file_path)
-    check_int(name='New fps', value=fps)
-    video_meta_data = get_video_meta_data(video_path=file_path)
-    dir_name, file_name, ext = get_fn_ext(filepath=file_path)
-    if int(fps) == int(video_meta_data['fps']):
-        print('SIMBA WARNING: The new fps is the same as the input fps for video {}'.format(file_name))
-    save_path = os.path.join(dir_name, file_name + '_fps_{}{}'.format(str(fps), str(ext)))
-    if os.path.isfile(save_path):
-        print('SIMBA WARNING: Overwriting existing file at {}'.format(save_path))
-    command = str('ffmpeg -i ') + '"' + str(file_path) + '"' + ' -filter:v fps=fps=' + str(fps) + ' ' + '"' + save_path + '"'
-    subprocess.call(command, shell=True)
-    print('SIMBA COMPLETE: FPS of video {} changed from {} to {} and saved in directory {}'.format(file_name, str(video_meta_data['fps']), str(fps), save_path))
-
-
-def change_fps_of_multiple_videos(directory: str,
-                                  fps: int):
-    """
-    Helper to change the fps of video files in a folder. Results are stored in the same directory as in the input files with
-    the suffix ``_fps_new_fps``.
-
-    Parameters
-    ----------
-    file_path: str
-        Path to video file.
-    fps: int
-        Fps of the new video file
-    """
-
-    if not os.path.isdir(directory):
-        print('SIMBA ERROR: {} is not a valid directory'.format(directory))
-        raise NotADirectoryError()
-    check_int(name='New fps', value=fps)
-    video_paths = []
-    file_paths_in_folder = [f for f in glob.glob(directory + '/*') if os.path.isfile(f)]
-    for file_path in file_paths_in_folder:
-        _, _, ext = get_fn_ext(filepath=file_path)
-        if ext.lower() in ['.avi', '.mp4', '.mov', '.flv']:
-            video_paths.append(file_path)
-    if len(video_paths) < 1:
-        print('SIMBA ERROR: No files with .mp4, .avi, .mov, .flv file ending found in the {} directory'.format(directory))
+    if len(file_lst) < 1:
+        print('SIMBA ERROR: No data files located in your project_folder/csv sub-directories in the worflow file format {}'.format(file_type))
         raise ValueError()
-    for file_cnt, file_path in enumerate(video_paths):
-        dir_name, file_name, ext = get_fn_ext(filepath=file_path)
-        save_path = os.path.join(dir_name, file_name + '_fps_{}{}'.format(str(fps), str(ext)))
-        command = str('ffmpeg -i ') + str(file_path) + ' -filter:v fps=fps=' + str(fps) + ' ' + '"' + save_path + '"'
-        subprocess.call(command, shell=True)
-        print('Video {} complete...'.format(file_name))
-    print('SIMBA COMPLETE: FPS of {} videos changed to {}'.format(str(len(video_paths)), str(fps)))
 
+    for file_path in file_lst:
+        file_folder = os.path.dirname(file_path)
+        save_directory = os.path.join(file_folder, archive_name)
+        save_file_path = os.path.join(save_directory, os.path.basename(file_path))
+        if not os.path.exists(save_directory): os.mkdir(save_directory)
+        print('Moving file {}...'.format(file_path))
+        shutil.move(file_path, save_file_path)
 
-def convert_video_powerpoint_compatible_format(file_path: str):
-    """
-    Helper to make a powerpoint compatible copy of a video file. The results is stored in the same directory as the
-    input file with the ``_powerpointready`` suffix.
+    log_archive_path = os.path.join(log_path, archive_name)
+    if not os.path.exists(log_archive_path): os.mkdir(log_archive_path)
+    if os.path.isfile(video_info_path):
+        save_file_path = os.path.join(log_archive_path, 'video_info.csv')
+        print('Moving file {}...'.format(video_info_path))
+        shutil.move(video_info_path, save_file_path)
 
-    Parameters
-    ----------
-    file_path: str
-        Path to video file.
+    videos_file_paths = [f for f in glob.glob(videos_dir) if os.path.isfile(f)]
+    video_archive_path = os.path.join(videos_dir, archive_name)
+    if not os.path.exists(video_archive_path): os.mkdir(video_archive_path)
+    for video_file in videos_file_paths:
+        save_video_path = os.path.join(video_archive_path, os.path.basename(video_file))
+        shutil.move(video_file, save_video_path)
 
-    """
-
-
-    check_file_exist_and_readable(file_path=file_path)
-    dir, file_name, ext = get_fn_ext(filepath=file_path)
-    save_name = os.path.join(dir, file_name + '_powerpointready.mp4')
-    if os.path.isfile(save_name):
-        print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
-        raise FileExistsError()
-    command = (str('ffmpeg -i ') + '"' + str(file_path) + '"' + ' -c:v libx264 -preset slow  -profile:v high -level:v 4.0 -pix_fmt yuv420p -crf 22 -codec:a aac ' + '"' + save_name + '"')
-    print('Creating video in powerpoint compatible format... ')
-    subprocess.call(command, shell=True, stdout=subprocess.PIPE)
-    print('SIMBA COMPLETE: Video converted! {} generated!'.format(save_name))
-
-def convert_to_mp4(file_path: str):
-    """
-    Helper to convert a video file to mp4 format. The results is stored in the same directory as the
-    input file with the ``_converted.mp4`` suffix.
-
-    Parameters
-    ----------
-    file_path: str
-        Path to video file.
-
-    """
-
-    check_file_exist_and_readable(file_path=file_path)
-    dir, file_name, ext = get_fn_ext(filepath=file_path)
-    save_name = os.path.join(dir, file_name + '_converted.mp4')
-    if os.path.isfile(save_name):
-        print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
-        raise FileExistsError()
-    command = (str('ffmpeg -i ') + '"' + str(file_path) + '"' + ' ' + '"' + save_name + '"')
-    print('Converting to mp4... ')
-    subprocess.call(command, shell=True, stdout=subprocess.PIPE)
-    print('SIMBA COMPLETE: Video converted! {} generated!'.format(save_name))
-
-
-def video_to_greyscale(file_path: str):
-    """
-    Helper to convert a video file to greyscale mp4 format. The results is stored in the same directory as the
-    input file with the ``_grayscale.mp4`` suffix.
-
-    Parameters
-    ----------
-    file_path: str
-        Path to video file.
-
-    """
-
-    check_file_exist_and_readable(file_path=file_path)
-    dir, file_name, ext = get_fn_ext(filepath=file_path)
-    save_name = os.path.join(dir, file_name + '_grayscale.mp4')
-    if os.path.isfile(save_name):
-        print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
-        raise FileExistsError()
-    command = (str('ffmpeg -i ') + '"' + str(file_path) + '"' + ' -vf format=gray ' + '"' + save_name + '"')
-    print('Converting to greyscale... ')
-    subprocess.call(command, shell=True, stdout=subprocess.PIPE)
-    print('SIMBA COMPLETE: Video converted! {} generated!'.format(save_name))
-
-
-def superimpose_frame_count(file_path: str):
-    """
-    Helper to superimpose frame count on a video file. The results is stored in the same directory as the
-    input file with the ``_frame_no.mp4`` suffix.
-
-    Parameters
-    ----------
-    file_path: str
-        Path to video file.
-
-    """
-
-
-    check_file_exist_and_readable(file_path=file_path)
-    dir, file_name, ext = get_fn_ext(filepath=file_path)
-    save_name = os.path.join(dir, file_name + '_frame_no.mp4')
-    print('Superimposing frame numbers...... ')
-    try:
-        command = (str('ffmpeg -y -i ') + '"' + file_path + '"' + ' -vf "drawtext=fontfile=Arial.ttf: text=\'%{frame_num}\': start_number=0: x=(w-tw)/2: y=h-(2*lh): fontcolor=black: fontsize=20: box=1: boxcolor=white: boxborderw=5" -c:a copy ' + '"' + save_name + '"')
-        subprocess.check_output(command, shell=True)
-        subprocess.call(command, shell=True, stdout=subprocess.PIPE)
-    except subprocess.CalledProcessError as e:
-        simba_cw = os.path.dirname(simba.__file__)
-        simba_font_path = Path(simba_cw, 'assets', 'UbuntuMono-Regular.ttf')
-        command = 'ffmpeg -y -i ' + file_path + ' -vf "drawtext=fontfile={}:'.format(simba_font_path) + "text='%{frame_num}': start_number=1: x=(w-tw)/2: y=h-(2*lh): fontcolor=black: fontsize=20: box=1: boxcolor=white: boxborderw=5" + '" ' + "-c:a copy " + save_name
-        subprocess.call(command, shell=True, stdout=subprocess.PIPE)
-    print('SIMBA COMPLETE: Video converted! {} generated!'.format(save_name))
-
-
-
-def remove_beginning_of_video(file_path: str,
-                              time: int):
-    """
-    Helper to remove N seconds from the beginning of a video file. The results is stored in the same directory as the
-    input file with the ``_shorten.mp4`` suffix.
-
-    Parameters
-    ----------
-    file_path: str
-        Path to video file.
-    """
-
-    check_file_exist_and_readable(file_path=file_path)
-    check_int(name='Cut time', value=time)
-    dir, file_name, ext = get_fn_ext(filepath=file_path)
-    save_name = os.path.join(dir, file_name + '_shorten.mp4')
-    if os.path.isfile(save_name):
-        print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
-        raise FileExistsError()
-    command = (str('ffmpeg -ss ') + str(int(time)) + ' -i ' + '"' + str(file_path) + '"' + ' -c:v libx264 -c:a aac ' + '"' + save_name + '"')
-    print('Shortening video... ')
-    subprocess.call(command, shell=True, stdout=subprocess.PIPE)
-    print('SIMBA COMPLETE: Video converted! {} generated!'.format(save_name))
-
-
-
-def clip_video_in_range(file_path: str,
-                        start_time: str,
-                        end_time: str):
-    """
-    Helper to clip video in a specific range. The results is stored in the same directory as the
-    input file with the ``_clipped.mp4`` suffix.
-
-    Parameters
-    ----------
-    file_path: str
-        Path to video file.
-    start_time: str
-        Start time of clip in HH:MM:SS format.
-    end_time: str
-        End time of clip in HH:MM:SS format.
-    """
-
-    check_file_exist_and_readable(file_path=file_path)
-    dir, file_name, ext = get_fn_ext(filepath=file_path)
-    save_name = os.path.join(dir, file_name + '_clipped.mp4')
-    if os.path.isfile(save_name):
-        print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
-        raise FileExistsError()
-    command = (str('ffmpeg -i ') + '"' + str(file_path) + '"' + ' -ss ' + str(start_time) + ' -to ' + str(end_time) + ' -async 1 ' + '"' + save_name + '"')
-    print('Clipping video... ')
-    subprocess.call(command, shell=True, stdout=subprocess.PIPE)
-    print('SIMBA COMPLETE: Video converted! {} generated!'.format(save_name))
+    print('SIMBA COMPLETE: Archiving completed.')
 
