@@ -132,7 +132,7 @@ class TresholdPlotCreator(object):
         start_time = time.time()
         for file_cnt, file_path in enumerate(self.files_found):
             _, self.video_name, _ = get_fn_ext(file_path)
-            video_info, self.px_per_mm, self.fps = read_video_info(vidinfDf=self.vid_info_df, currVidName=self.video_name)
+            video_info, self.px_per_mm, self.fps = read_video_info(vid_info_df=self.vid_info_df, video_name=self.video_name)
             data_df = read_df(file_path, self.file_type)
             check_that_column_exist(df=data_df, column_name=self.clf_name, file_name=self.video_name)
             if self.frame_setting:
