@@ -33,13 +33,14 @@ def read_all_files_in_folder(file_paths: list,
                              classifier_names=None):
     """
 
-    Helper function to read in all data files in a folder for downstream ML algorithm.
+    Helper function to read in all data files in a folder to a cingle pd.DataFrame for downstream ML algorithm.
+    Asserts that all classifiers have annotation fields present in concatenated dataframes.
 
     Parameters
     ----------
     file_paths: list
         List of file paths representing files to be read in.
-    file_type
+    file_type: str
         Type of files in ``file_paths``. OPTIONS: csv or parquet.
     classifier_names: list or None
         List of classifier names representing fields of human annotations. If not None, then assert that classifier names
@@ -77,7 +78,7 @@ def read_all_files_in_folder(file_paths: list,
 
 def read_in_all_model_names_to_remove(config, model_cnt, clf_name):
     """
-    Helper function find all fields that contain annotations but are not the target.
+    Helper to find all field names that contain annotations but are not the target.
 
     Parameters
     ----------
@@ -103,7 +104,7 @@ def read_in_all_model_names_to_remove(config, model_cnt, clf_name):
 def delete_other_annotation_columns(df: pd.DataFrame,
                                     annotations_lst: list):
     """
-    Helper function delete all fields that contain annotations but are not the target.
+    Helper to delete fields that contain annotations which are not the target.
 
     Parameters
     ----------
@@ -123,6 +124,22 @@ def delete_other_annotation_columns(df: pd.DataFrame,
 
 def split_df_to_x_y(df: pd.DataFrame,
                     clf_name: str):
+    """
+    Helper to split dataframe into features and target.
+
+    Parameters
+    ----------
+    df: pd.DataFrame
+        pandas Dataframe holding features and annotations.
+    clf_name: str
+        Name of target.
+
+    Returns
+    -------
+    df: pd.DataFrame
+    y: pd.DataFrame
+    """
+
     df = deepcopy(df)
     y = df.pop(clf_name)
     return df, y
@@ -642,7 +659,7 @@ def print_machine_model_information(model_dict: dict):
     Parameters
     ----------
     model_dict: dict
-        Python dictionary holding model meta data
+        Python dictionary holding model meta data in SimBA meta-config format.
 
     Returns
     -------
